
# APISpec Pydantic Plugin

This is a plugin that replaces `apispec.ext.marshmallow:MarshmallowPlugin` with an equivalent plugin for use with Pydantic.



## Acknowledgements

 - [APISpec's Marshmallow Plugin ](https://github.com/marshmallow-code/apispec/tree/dev/src/apispec/ext/marshmallow)
- [challice-spec](https://github.com/TestBoxLab/chalice-spec)